@apply
class Undefined:
	pass

class Assembly:
	pass

class CallMethodError(Exception):
	pass

class Girl:
	pass

Ella = Agent = Girl

class ParallelTask:
	pass

class Programmer:
	NONE = None

	def __init__(self, principal):
		pass

class Script:
	@classmethod
	def debugInstruction(self, *args, **kwd):
		pass


class Volume:
	pass

def callGirlMethod(*args, **kwd):
	pass

def executeGirl(*args, **kwd):
	pass

def getLibraryCore(*args, **kwd):
	pass

def invokeLibraryMethod(*args, **kwd):
	pass

def newModuleTask(*args, **kwd):
	pass


def findUser(*args, **kwd):
	pass

def findUserByName(*args, **kwd):
	pass

def findCurrentUser(*args, **kwd):
	pass

class nullproc:
	pass
